@@ -709,7 +709,8 @@ class VariableClAutopartitionBiosGrubSet(ReadonlyVariable):
 
     def get(self):
         if (self.GetBool('cl_autopartition_set') and
-                    self.Get('cl_autopartition_table') == 'gpt'):
+                    self.Get('cl_autopartition_table') == 'gpt' and
+                    self.Get('cl_autopartition_uefi_set') == 'off'):
             return "on"
         return "off"
 
