@@ -30,9 +30,8 @@ from calculate.lib.utils.common import getValueFromConfig, getValueFromCmdLine
 from calculate.lib.utils.common import getUserPrimaryGroup
 from calculate.lib.utils.portage import isPkgInstalled
 from calculate.lib.utils.device import getUdevDeviceInfo
-from crypt import crypt
 from autopartition import SchemeOpt, SchemeDevices
-from calculate.lib.encrypt import encrypt, get_shadow_hash, get_grub_hash
+from calculate.lib.encrypt import get_shadow_hash, get_grub_hash
 import calculate.lib.cl_ini_parser as cl_ini_parser
 
 from calculate.lib.cl_lang import setLocalTranslate, _
@@ -156,8 +155,9 @@ class VariableClMigrateRootShadowPwd(ReadonlyVariable):
         else:
             rootPasswd = ""
         # if root password is "root"
-        if rootPasswd:
-            if get_shadow_hash().verify("root", rootPasswd):
+        enc = get_shadow_hash()
+        if rootPasswd and enc.identify(rootPasswd):
+            if enc.verify("root", rootPasswd):
                 rootPasswd = ""
         return rootPasswd or ""
 
